/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02995
 |            UNIFORM FACILITY DATA SET, 1997: [UNITED STATES]
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02995-0001-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Uniform Facility Data Set, 1997: [United States]"

#delimit ;
label define MODE      -9 "MISSING" 1 "TELEPHONE FOLLOW-UP" 2 "MAIL SURVEY" ;
label define STFIPS    -9 "MISSING" 1 "ALABAMA" 2 "ALASKA" 3 "ARKANSAS"
                       4 "ARIZONA" 5 "ARKANSAS" 6 "CALIFORNIA"
                       7 "CONNECTICUT" 8 "COLORADO" 9 "CONNECTICUT"
                       10 "DELAWARE" 11 "DIST OF COLUMBIA" 12 "FLORIDA"
                       13 "GEORGIA" 14 "IDAHO" 15 "HAWAII" 16 "IDAHO"
                       17 "ILLINOIS" 18 "INDIANA" 19 "IOWA" 20 "KANSAS"
                       21 "KENTUCKY" 22 "LOUISIANA" 23 "MAINE" 24 "MARYLAND"
                       25 "MASSACHUSETTS" 26 "MICHIGAN" 27 "MINNESOTA"
                       28 "MISSISSIPPI" 29 "MISSOURI" 30 "MONTANA"
                       31 "NEBRASKA" 32 "NEVADA" 33 "NEW HAMPSHIRE"
                       34 "NEW JERSEY" 35 "NEW MEXICO" 36 "NEW YORK"
                       37 "NORTH CAROLINA" 38 "NORTH DAKOTA" 39 "OHIO"
                       40 "OKLAHOMA" 41 "OREGON" 42 "PENNSYLVANIA"
                       43 "SOUTH DAKOTA" 44 "RHODE ISLAND"
                       45 "SOUTH CAROLINA" 46 "SOUTH DAKOTA" 47 "TENNESSEE"
                       48 "TEXAS" 49 "UTAH" 50 "VERMONT" 51 "VIRGINIA"
                       52 "WYOMING" 53 "WASHINGTON" 54 "WEST VIRGINIA"
                       55 "WISCONSIN" 56 "WYOMING" 57 "VIRGIN ISLANDS"
                       60 "AMERICAN SAMOA" 64 "FED MICRONESIA" 66 "GUAM"
                       70 "PALAU" 72 "PUERTO RICO" 78 "VIRGIN ISLANDS" ;
label define TREATMT   -9 "MISSING" 1 "YES" ;
label define PREVNTN   -9 "MISSING" 0 "NO" 1 "YES" ;
label define OTHNONTX  -9 "MISSING" 0 "NO" 1 "YES" ;
label define OWNERSHP  -9 "MISSING" 1 "PRIVATE-FOR-PROFIT"
                       2 "PRIVATE NON-PROFIT" 3 "STATE GOVERNMENT"
                       4 "LOCAL GOVERNMENT" 5 "TRIBAL GOVERNMENT"
                       6 "FEDERAL GOVERNMENT" ;
label define FEDOWN    -9 "MISSING" 1 "DEPT OF VETERANS AFFAIRS"
                       2 "DEPT OF DEFENSE" 4 "INDIAN HEALTH SVC" 5 "OTHER" ;
label define HOTYN     -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC1      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC2      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC3      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC4      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC5      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC6      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC7      -9 "MISSING" 1 "YES" 2 "NO" ;
label define LOC8      -9 "MISSING" 1 "YES" 2 "NO" ;
label define MGMCARE   -9 "MISSING" 1 "YES" 2 "NO" ;
label define WRITARRA  -9 "MISSING" 1 "YES" 2 "NO" ;
label define WRITNUM   -9 "MISSING" ;
label define NEWSET2   -9 "MISSING" 1 "GENERAL HOSPITAL"
                       2 "PSYCH./OTHER(NON-VA)SPECIALIZED HOSPITAL"
                       3 "SOLO AND GROUP PRACTICES" 4 "CRIMINAL JUSTICE"
                       5 "COMMUNITY MH CENTER OR OTHER MH FACILITY"
                       6 "COMMUNITY HEALTH CENTER" 7 "MIXED/OTHER"
                       8 "OUTPATIENT" 9 "RESIDENTIAL" 10 "OP & RESID"
                       11 "COMMUNITY OR RELIGIOUS AGENCY/ORG." ;
label define ADMIN     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SETTING   -9 "MISSING" 1 "GENERAL HOSPITAL"
                       2 "PSYCHIATRIC HOSPITAL"
                       3 "OTHER SPECIALIZED HOSPITAL" 4 "SOLO PRACTICE"
                       5 "GROUP PRACTICE"
                       6 "SCHOOL (ELEM., SECONDARY, COLLEGE-UNIV.)"
                       7 "JAIL, PRISON, JUVENILE DETENTION CENTER"
                       8 "OTHER CRIMINAL JUSTICE" 9 "OTHER SETTING" ;
label define WAITLIST  -9 "MISSING" 1 "YES" 2 "NO" ;
label define WAITNUM   -9 "MISSING" ;
label define SRVC1     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC2     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC3     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC4     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC5     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC6     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC7     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC8     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC9     -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC10    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC11    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC12    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC13    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC14    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC15    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC16    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC17    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC18    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC19    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC20    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC21    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC22    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC23    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC24    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC25    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC26    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC27    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC28    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC29    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC31    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC35    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC36    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC37    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC38    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC39    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC40    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC41    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC42    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC43    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC44    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC45    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC46    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC47    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC48    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC49    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC50    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC51    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC52    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC53    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC54    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC55    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC56    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC57    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC58    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC59    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC60    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC61    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC30    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC32    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC33    -9 "MISSING" 0 "NO" 1 "YES" ;
label define SRVC34    -9 "MISSING" 0 "NO" 1 "YES" ;
label define METLAAM   -9 "MISSING" 1 "YES" 2 "NO" ;
label define CLIEST    -9 "MISSING" 1 "ACTUAL COUNT" 2 "ESTIMATE" ;
label define HOSPRES   -9 "MISSING" 1 "YES" ;
label define DEMOGEST  -9 "MISSING" 1 "ACTUAL ACTIVE CLIENT COUNTS"
                       2 "ESTIMATE" ;
label define METNUM    -9 "MISSING" ;
label define LAAMNUM   -9 "MISSING" ;
label define PREGNUM   -9 "MISSING" ;
label define DEPNUM    -9 "MISSING" ;
label define INJNUM    -9 "MISSING" ;
label define TBNUM     -9 "MISSING" ;
label define HIVNUM    -9 "MISSING" ;
label define PREVNUM   -9 "MISSING" ;
label define MGDNUM    -9 "MISSING" ;
label define CJNUM     -9 "MISSING" ;
label define PARENT    -9 "MISSING" 1 "YES" 2 "NO" ;
label define NUMSUBS   -9 "MISSING" ;
label define ADMINLNK  -9 "MISSING" 1 "YES" 2 "NO" ;
label define OTHFAC    -9 "MISSING" 1 "YES" 2 "NO" ;
label define OTHNUM    -9 "MISSING" 1 "2 SITES" 2 "3-5 SITES" 3 "6-10 SITES"
                       4 "MORE THAN 10 SITES" ;
label define T_CLI1    -9 "MISSING" ;
label define T_CLI2    -9 "MISSING" ;
label define HOSPBED   -9 "MISSING" ;
label define H_AGE1    -9 "MISSING" ;
label define H_AGE2    -9 "MISSING" ;
label define H_AGE3    -9 "MISSING" ;
label define H_AGE4    -9 "MISSING" ;
label define H_AGE5    -9 "MISSING" ;
label define H_AGE6    -9 "MISSING" ;
label define H_AGE7    -9 "MISSING" ;
label define H_AGE9    -9 "MISSING" ;
label define H_RE1     -9 "MISSING" ;
label define H_RE2     -9 "MISSING" ;
label define H_RE3     -9 "MISSING" ;
label define H_RE4     -9 "MISSING" ;
label define H_RE5     -9 "MISSING" ;
label define H_RE6     -9 "MISSING" ;
label define H_RE8     -9 "MISSING" ;
label define H_SEX1    -9 "MISSING" ;
label define H_SEX2    -9 "MISSING" ;
label define H_SEX4    -9 "MISSING" ;
label define T_CLI3    -9 "MISSING" ;
label define T_CLI4    -9 "MISSING" ;
label define RESBED    -9 "MISSING" ;
label define R_AGE1    -9 "MISSING" ;
label define R_AGE2    -9 "MISSING" ;
label define R_AGE3    -9 "MISSING" ;
label define R_AGE4    -9 "MISSING" ;
label define R_AGE5    -9 "MISSING" ;
label define R_AGE6    -9 "MISSING" ;
label define R_AGE7    -9 "MISSING" ;
label define R_AGE9    -9 "MISSING" ;
label define R_RE1     -9 "MISSING" ;
label define R_RE2     -9 "MISSING" ;
label define R_RE3     -9 "MISSING" ;
label define R_RE4     -9 "MISSING" ;
label define R_RE5     -9 "MISSING" ;
label define R_RE6     -9 "MISSING" ;
label define R_RE8     -9 "MISSING" ;
label define R_SEX1    -9 "MISSING" ;
label define R_SEX2    -9 "MISSING" ;
label define R_SEX4    -9 "MISSING" ;
label define T_CLI5    -9 "MISSING" ;
label define T_CLI6    -9 "MISSING" ;
label define O_AGE1    -9 "MISSING" ;
label define O_AGE2    -9 "MISSING" ;
label define O_AGE3    -9 "MISSING" ;
label define O_AGE4    -9 "MISSING" ;
label define O_AGE5    -9 "MISSING" ;
label define O_AGE6    -9 "MISSING" ;
label define O_AGE7    -9 "MISSING" ;
label define O_AGE9    -9 "MISSING" ;
label define O_RE1     -9 "MISSING" ;
label define O_RE2     -9 "MISSING" ;
label define O_RE3     -9 "MISSING" ;
label define O_RE4     -9 "MISSING" ;
label define O_RE5     -9 "MISSING" ;
label define O_RE6     -9 "MISSING" ;
label define O_RE8     -9 "MISSING" ;
label define O_SEX1    -9 "MISSING" ;
label define O_SEX2    -9 "MISSING" ;
label define O_SEX4    -9 "MISSING" ;
label define T_CLI7    -9 "MISSING" ;
label define A_NUM     -9 "MISSING" ;
label define D_NUM     -9 "MISSING" ;
label define B_NUM     -9 "MISSING" ;
label define A_PCT     -9 "MISSING" ;
label define D_PCT     -9 "MISSING" ;
label define B_PCT     -9 "MISSING" ;
label define T_AGE1    -9 "MISSING" ;
label define T_AGE2    -9 "MISSING" ;
label define T_AGE3    -9 "MISSING" ;
label define T_AGE4    -9 "MISSING" ;
label define T_AGE5    -9 "MISSING" ;
label define T_AGE6    -9 "MISSING" ;
label define T_AGE7    -9 "MISSING" ;
label define T_AGE9    -9 "MISSING" ;
label define T_RE1     -9 "MISSING" ;
label define T_RE2     -9 "MISSING" ;
label define T_RE3     -9 "MISSING" ;
label define T_RE4     -9 "MISSING" ;
label define T_RE5     -9 "MISSING" ;
label define T_RE6     -9 "MISSING" ;
label define T_RE8     -9 "MISSING" ;
label define T_SEX1    -9 "MISSING" ;
label define T_SEX2    -9 "MISSING" ;
label define T_SEX4    -9 "MISSING" ;
label define PREGPCT   -9 "MISSING" ;
label define DEPPCT    -9 "MISSING" ;
label define INJPCT    -9 "MISSING" ;
label define TBPCT     -9 "MISSING" ;
label define HIVPCT    -9 "MISSING" ;
label define PREVPCT   -9 "MISSING" ;
label define MGDPCT    -9 "MISSING" ;
label define CJPCT     -9 "MISSING" ;
label define ADMITNUM  -9 "MISSING" ;
label define ADMITEST  -9 "MISSING" 1 "ACTUAL COUNT" 2 "BEST ESTIMATE" ;
label define UNDUPEST  -9 "MISSING" 1 "ACTUAL COUNT" 2 "BEST ESTIMATE" ;
label define T_AG1FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG4FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG5FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG6FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG7FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG7FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG7FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG7FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE1FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE2FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE3FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE4FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE5FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE6FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE5FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE6FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_SX1FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_SX2FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_SX1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_SX2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_SX1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_SX2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_SX1FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_SX2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG2FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG3FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_AG9FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_AG9FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_AG9FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG2FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG3FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_AG9FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_RE8FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_RE8FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_RE8FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_RE8FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define T_SX4FL   -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define HI_SX4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define RC_SX4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;
label define OP_SX4FL  -9 "MISSING" 0 "VALUE NOT IMPUTED" 1 "VALUE IMPUTED" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace MODE = . if (MODE <= -1 )
replace STFIPS = . if (STFIPS <= -1 )
replace TREATMT = . if (TREATMT <= -1 )
replace PREVNTN = . if (PREVNTN <= -1 )
replace OTHNONTX = . if (OTHNONTX <= -1 )
replace OWNERSHP = . if (OWNERSHP <= -1 )
replace FEDOWN = . if (FEDOWN <= -1 )
replace HOTYN = . if (HOTYN <= -1 )
replace LOC1 = . if (LOC1 <= -1 )
replace LOC2 = . if (LOC2 <= -1 )
replace LOC3 = . if (LOC3 <= -1 )
replace LOC4 = . if (LOC4 <= -1 )
replace LOC5 = . if (LOC5 <= -1 )
replace LOC6 = . if (LOC6 <= -1 )
replace LOC7 = . if (LOC7 <= -1 )
replace LOC8 = . if (LOC8 <= -1 )
replace MGMCARE = . if (MGMCARE <= -1 )
replace WRITARRA = . if (WRITARRA <= -1 )
replace WRITNUM = . if (WRITNUM <= -1 )
replace NEWSET2 = . if (NEWSET2 <= -1 )
replace ADMIN = . if (ADMIN <= -1 )
replace SETTING = . if (SETTING <= -1 )
replace WAITLIST = . if (WAITLIST <= -1 )
replace WAITNUM = . if (WAITNUM <= -1 )
replace SRVC1 = . if (SRVC1 <= -1 )
replace SRVC2 = . if (SRVC2 <= -1 )
replace SRVC3 = . if (SRVC3 <= -1 )
replace SRVC4 = . if (SRVC4 <= -1 )
replace SRVC5 = . if (SRVC5 <= -1 )
replace SRVC6 = . if (SRVC6 <= -1 )
replace SRVC7 = . if (SRVC7 <= -1 )
replace SRVC8 = . if (SRVC8 <= -1 )
replace SRVC9 = . if (SRVC9 <= -1 )
replace SRVC10 = . if (SRVC10 <= -1 )
replace SRVC11 = . if (SRVC11 <= -1 )
replace SRVC12 = . if (SRVC12 <= -1 )
replace SRVC13 = . if (SRVC13 <= -1 )
replace SRVC14 = . if (SRVC14 <= -1 )
replace SRVC15 = . if (SRVC15 <= -1 )
replace SRVC16 = . if (SRVC16 <= -1 )
replace SRVC17 = . if (SRVC17 <= -1 )
replace SRVC18 = . if (SRVC18 <= -1 )
replace SRVC19 = . if (SRVC19 <= -1 )
replace SRVC20 = . if (SRVC20 <= -1 )
replace SRVC21 = . if (SRVC21 <= -1 )
replace SRVC22 = . if (SRVC22 <= -1 )
replace SRVC23 = . if (SRVC23 <= -1 )
replace SRVC24 = . if (SRVC24 <= -1 )
replace SRVC25 = . if (SRVC25 <= -1 )
replace SRVC26 = . if (SRVC26 <= -1 )
replace SRVC27 = . if (SRVC27 <= -1 )
replace SRVC28 = . if (SRVC28 <= -1 )
replace SRVC29 = . if (SRVC29 <= -1 )
replace SRVC31 = . if (SRVC31 <= -1 )
replace SRVC35 = . if (SRVC35 <= -1 )
replace SRVC36 = . if (SRVC36 <= -1 )
replace SRVC37 = . if (SRVC37 <= -1 )
replace SRVC38 = . if (SRVC38 <= -1 )
replace SRVC39 = . if (SRVC39 <= -1 )
replace SRVC40 = . if (SRVC40 <= -1 )
replace SRVC41 = . if (SRVC41 <= -1 )
replace SRVC42 = . if (SRVC42 <= -1 )
replace SRVC43 = . if (SRVC43 <= -1 )
replace SRVC44 = . if (SRVC44 <= -1 )
replace SRVC45 = . if (SRVC45 <= -1 )
replace SRVC46 = . if (SRVC46 <= -1 )
replace SRVC47 = . if (SRVC47 <= -1 )
replace SRVC48 = . if (SRVC48 <= -1 )
replace SRVC49 = . if (SRVC49 <= -1 )
replace SRVC50 = . if (SRVC50 <= -1 )
replace SRVC51 = . if (SRVC51 <= -1 )
replace SRVC52 = . if (SRVC52 <= -1 )
replace SRVC53 = . if (SRVC53 <= -1 )
replace SRVC54 = . if (SRVC54 <= -1 )
replace SRVC55 = . if (SRVC55 <= -1 )
replace SRVC56 = . if (SRVC56 <= -1 )
replace SRVC57 = . if (SRVC57 <= -1 )
replace SRVC58 = . if (SRVC58 <= -1 )
replace SRVC59 = . if (SRVC59 <= -1 )
replace SRVC60 = . if (SRVC60 <= -1 )
replace SRVC61 = . if (SRVC61 <= -1 )
replace SRVC30 = . if (SRVC30 <= -1 )
replace SRVC32 = . if (SRVC32 <= -1 )
replace SRVC33 = . if (SRVC33 <= -1 )
replace SRVC34 = . if (SRVC34 <= -1 )
replace METLAAM = . if (METLAAM <= -1 )
replace CLIEST = . if (CLIEST <= -1 )
replace HOSPRES = . if (HOSPRES <= -1 )
replace DEMOGEST = . if (DEMOGEST <= -1 )
replace METNUM = . if (METNUM <= -1 )
replace LAAMNUM = . if (LAAMNUM <= -1 )
replace PREGNUM = . if (PREGNUM <= -1 )
replace DEPNUM = . if (DEPNUM <= -1 )
replace INJNUM = . if (INJNUM <= -1 )
replace TBNUM = . if (TBNUM <= -1 )
replace HIVNUM = . if (HIVNUM <= -1 )
replace PREVNUM = . if (PREVNUM <= -1 )
replace MGDNUM = . if (MGDNUM <= -1 )
replace CJNUM = . if (CJNUM <= -1 )
replace PARENT = . if (PARENT <= -1 )
replace NUMSUBS = . if (NUMSUBS <= -1 )
replace ADMINLNK = . if (ADMINLNK <= -1 )
replace OTHFAC = . if (OTHFAC <= -1 )
replace OTHNUM = . if (OTHNUM <= -1 )
replace T_CLI1 = . if (T_CLI1 <= -1 )
replace T_CLI2 = . if (T_CLI2 <= -1 )
replace HOSPBED = . if (HOSPBED <= -1 )
replace H_AGE1 = . if (H_AGE1 <= -1 )
replace H_AGE2 = . if (H_AGE2 <= -1 )
replace H_AGE3 = . if (H_AGE3 <= -1 )
replace H_AGE4 = . if (H_AGE4 <= -1 )
replace H_AGE5 = . if (H_AGE5 <= -1 )
replace H_AGE6 = . if (H_AGE6 <= -1 )
replace H_AGE7 = . if (H_AGE7 <= -1 )
replace H_AGE9 = . if (H_AGE9 <= -1 )
replace H_RE1 = . if (H_RE1 <= -1 )
replace H_RE2 = . if (H_RE2 <= -1 )
replace H_RE3 = . if (H_RE3 <= -1 )
replace H_RE4 = . if (H_RE4 <= -1 )
replace H_RE5 = . if (H_RE5 <= -1 )
replace H_RE6 = . if (H_RE6 <= -1 )
replace H_RE8 = . if (H_RE8 <= -1 )
replace H_SEX1 = . if (H_SEX1 <= -1 )
replace H_SEX2 = . if (H_SEX2 <= -1 )
replace H_SEX4 = . if (H_SEX4 <= -1 )
replace T_CLI3 = . if (T_CLI3 <= -1 )
replace T_CLI4 = . if (T_CLI4 <= -1 )
replace RESBED = . if (RESBED <= -1 )
replace R_AGE1 = . if (R_AGE1 <= -1 )
replace R_AGE2 = . if (R_AGE2 <= -1 )
replace R_AGE3 = . if (R_AGE3 <= -1 )
replace R_AGE4 = . if (R_AGE4 <= -1 )
replace R_AGE5 = . if (R_AGE5 <= -1 )
replace R_AGE6 = . if (R_AGE6 <= -1 )
replace R_AGE7 = . if (R_AGE7 <= -1 )
replace R_AGE9 = . if (R_AGE9 <= -1 )
replace R_RE1 = . if (R_RE1 <= -1 )
replace R_RE2 = . if (R_RE2 <= -1 )
replace R_RE3 = . if (R_RE3 <= -1 )
replace R_RE4 = . if (R_RE4 <= -1 )
replace R_RE5 = . if (R_RE5 <= -1 )
replace R_RE6 = . if (R_RE6 <= -1 )
replace R_RE8 = . if (R_RE8 <= -1 )
replace R_SEX1 = . if (R_SEX1 <= -1 )
replace R_SEX2 = . if (R_SEX2 <= -1 )
replace R_SEX4 = . if (R_SEX4 <= -1 )
replace T_CLI5 = . if (T_CLI5 <= -1 )
replace T_CLI6 = . if (T_CLI6 <= -1 )
replace O_AGE1 = . if (O_AGE1 <= -1 )
replace O_AGE2 = . if (O_AGE2 <= -1 )
replace O_AGE3 = . if (O_AGE3 <= -1 )
replace O_AGE4 = . if (O_AGE4 <= -1 )
replace O_AGE5 = . if (O_AGE5 <= -1 )
replace O_AGE6 = . if (O_AGE6 <= -1 )
replace O_AGE7 = . if (O_AGE7 <= -1 )
replace O_AGE9 = . if (O_AGE9 <= -1 )
replace O_RE1 = . if (O_RE1 <= -1 )
replace O_RE2 = . if (O_RE2 <= -1 )
replace O_RE3 = . if (O_RE3 <= -1 )
replace O_RE4 = . if (O_RE4 <= -1 )
replace O_RE5 = . if (O_RE5 <= -1 )
replace O_RE6 = . if (O_RE6 <= -1 )
replace O_RE8 = . if (O_RE8 <= -1 )
replace O_SEX1 = . if (O_SEX1 <= -1 )
replace O_SEX2 = . if (O_SEX2 <= -1 )
replace O_SEX4 = . if (O_SEX4 <= -1 )
replace T_CLI7 = . if (T_CLI7 <= -1 )
replace A_NUM = . if (A_NUM <= -1 )
replace D_NUM = . if (D_NUM <= -1 )
replace B_NUM = . if (B_NUM <= -1 )
replace A_PCT = . if (A_PCT <= -1 )
replace D_PCT = . if (D_PCT <= -1 )
replace B_PCT = . if (B_PCT <= -1 )
replace T_AGE1 = . if (T_AGE1 <= -1 )
replace T_AGE2 = . if (T_AGE2 <= -1 )
replace T_AGE3 = . if (T_AGE3 <= -1 )
replace T_AGE4 = . if (T_AGE4 <= -1 )
replace T_AGE5 = . if (T_AGE5 <= -1 )
replace T_AGE6 = . if (T_AGE6 <= -1 )
replace T_AGE7 = . if (T_AGE7 <= -1 )
replace T_AGE9 = . if (T_AGE9 <= -1 )
replace T_RE1 = . if (T_RE1 <= -1 )
replace T_RE2 = . if (T_RE2 <= -1 )
replace T_RE3 = . if (T_RE3 <= -1 )
replace T_RE4 = . if (T_RE4 <= -1 )
replace T_RE5 = . if (T_RE5 <= -1 )
replace T_RE6 = . if (T_RE6 <= -1 )
replace T_RE8 = . if (T_RE8 <= -1 )
replace T_SEX1 = . if (T_SEX1 <= -1 )
replace T_SEX2 = . if (T_SEX2 <= -1 )
replace T_SEX4 = . if (T_SEX4 <= -1 )
replace PREGPCT = . if (PREGPCT <= -1 )
replace DEPPCT = . if (DEPPCT <= -1 )
replace INJPCT = . if (INJPCT <= -1 )
replace TBPCT = . if (TBPCT <= -1 )
replace HIVPCT = . if (HIVPCT <= -1 )
replace PREVPCT = . if (PREVPCT <= -1 )
replace MGDPCT = . if (MGDPCT <= -1 )
replace CJPCT = . if (CJPCT <= -1 )
replace ADMITNUM = . if (ADMITNUM <= -1 )
replace ADMITEST = . if (ADMITEST <= -1 )
replace UNDUPEST = . if (UNDUPEST <= -1 )
replace T_AG1FL = . if (T_AG1FL <= -1 )
replace T_AG4FL = . if (T_AG4FL <= -1 )
replace T_AG5FL = . if (T_AG5FL <= -1 )
replace T_AG6FL = . if (T_AG6FL <= -1 )
replace T_AG7FL = . if (T_AG7FL <= -1 )
replace HI_AG1FL = . if (HI_AG1FL <= -1 )
replace HI_AG4FL = . if (HI_AG4FL <= -1 )
replace HI_AG5FL = . if (HI_AG5FL <= -1 )
replace HI_AG6FL = . if (HI_AG6FL <= -1 )
replace HI_AG7FL = . if (HI_AG7FL <= -1 )
replace RC_AG1FL = . if (RC_AG1FL <= -1 )
replace RC_AG4FL = . if (RC_AG4FL <= -1 )
replace RC_AG5FL = . if (RC_AG5FL <= -1 )
replace RC_AG6FL = . if (RC_AG6FL <= -1 )
replace RC_AG7FL = . if (RC_AG7FL <= -1 )
replace OP_AG1FL = . if (OP_AG1FL <= -1 )
replace OP_AG4FL = . if (OP_AG4FL <= -1 )
replace OP_AG5FL = . if (OP_AG5FL <= -1 )
replace OP_AG6FL = . if (OP_AG6FL <= -1 )
replace OP_AG7FL = . if (OP_AG7FL <= -1 )
replace T_RE1FL = . if (T_RE1FL <= -1 )
replace T_RE2FL = . if (T_RE2FL <= -1 )
replace T_RE3FL = . if (T_RE3FL <= -1 )
replace T_RE4FL = . if (T_RE4FL <= -1 )
replace T_RE5FL = . if (T_RE5FL <= -1 )
replace T_RE6FL = . if (T_RE6FL <= -1 )
replace HI_RE1FL = . if (HI_RE1FL <= -1 )
replace HI_RE2FL = . if (HI_RE2FL <= -1 )
replace HI_RE3FL = . if (HI_RE3FL <= -1 )
replace HI_RE4FL = . if (HI_RE4FL <= -1 )
replace HI_RE5FL = . if (HI_RE5FL <= -1 )
replace HI_RE6FL = . if (HI_RE6FL <= -1 )
replace RC_RE1FL = . if (RC_RE1FL <= -1 )
replace RC_RE2FL = . if (RC_RE2FL <= -1 )
replace RC_RE3FL = . if (RC_RE3FL <= -1 )
replace RC_RE4FL = . if (RC_RE4FL <= -1 )
replace RC_RE5FL = . if (RC_RE5FL <= -1 )
replace RC_RE6FL = . if (RC_RE6FL <= -1 )
replace OP_RE1FL = . if (OP_RE1FL <= -1 )
replace OP_RE2FL = . if (OP_RE2FL <= -1 )
replace OP_RE3FL = . if (OP_RE3FL <= -1 )
replace OP_RE4FL = . if (OP_RE4FL <= -1 )
replace OP_RE5FL = . if (OP_RE5FL <= -1 )
replace OP_RE6FL = . if (OP_RE6FL <= -1 )
replace T_SX1FL = . if (T_SX1FL <= -1 )
replace T_SX2FL = . if (T_SX2FL <= -1 )
replace HI_SX1FL = . if (HI_SX1FL <= -1 )
replace HI_SX2FL = . if (HI_SX2FL <= -1 )
replace RC_SX1FL = . if (RC_SX1FL <= -1 )
replace RC_SX2FL = . if (RC_SX2FL <= -1 )
replace OP_SX1FL = . if (OP_SX1FL <= -1 )
replace OP_SX2FL = . if (OP_SX2FL <= -1 )
replace T_AG2FL = . if (T_AG2FL <= -1 )
replace T_AG3FL = . if (T_AG3FL <= -1 )
replace T_AG9FL = . if (T_AG9FL <= -1 )
replace HI_AG2FL = . if (HI_AG2FL <= -1 )
replace HI_AG3FL = . if (HI_AG3FL <= -1 )
replace HI_AG9FL = . if (HI_AG9FL <= -1 )
replace RC_AG2FL = . if (RC_AG2FL <= -1 )
replace RC_AG3FL = . if (RC_AG3FL <= -1 )
replace RC_AG9FL = . if (RC_AG9FL <= -1 )
replace OP_AG2FL = . if (OP_AG2FL <= -1 )
replace OP_AG3FL = . if (OP_AG3FL <= -1 )
replace OP_AG9FL = . if (OP_AG9FL <= -1 )
replace T_RE8FL = . if (T_RE8FL <= -1 )
replace HI_RE8FL = . if (HI_RE8FL <= -1 )
replace RC_RE8FL = . if (RC_RE8FL <= -1 )
replace OP_RE8FL = . if (OP_RE8FL <= -1 )
replace T_SX4FL = . if (T_SX4FL <= -1 )
replace HI_SX4FL = . if (HI_SX4FL <= -1 )
replace RC_SX4FL = . if (RC_SX4FL <= -1 )
replace OP_SX4FL = . if (OP_SX4FL <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

